@@ -1,7 +1,7 @@
 """Communicates with databases using repository pattern and service patterns"""
 
 
-__version__ = '0.4.1'
+__version__ = '0.5.0'
 
 
 from dbdaora.cache import CacheType
@@ -11,7 +11,6 @@ from dbdaora.data_sources.fallback.dict import DictFallbackDataSource
 from dbdaora.data_sources.memory import MemoryDataSource
 from dbdaora.data_sources.memory.dict import DictMemoryDataSource
 from dbdaora.exceptions import EntityNotFoundError
-from dbdaora.hash.entity import HashEntity
 from dbdaora.hash.factory import make_service as make_hash_service
 from dbdaora.hash.query import HashQuery, HashQueryMany
 from dbdaora.hash.repositories import HashData, HashRepository
@@ -32,9 +31,13 @@ from dbdaora.sorted_set.repositories import SortedSetRepository
 try:
     from dbdaora.data_sources.fallback.datastore import DatastoreDataSource
     from dbdaora.hash.repositories.datastore import DatastoreHashRepository
+    from dbdaora.sorted_set.repositories.datastore import (
+        DatastoreSortedSetRepository,
+    )
 except ImportError:
     DatastoreDataSource = None  # type: ignore
     DatastoreHashRepository = None  # type: ignore
+    DatastoreSortedSetRepository = None  # type: ignore
 
 
 try:
@@ -67,7 +70,6 @@ __all__ = [
     'build_service',
     'CacheType',
     'Service',
-    'HashEntity',
     'EntityNotFoundError',
     'HashQueryMany',
     'make_hash_service',
@@ -89,3 +91,6 @@ if DatastoreDataSource:
 
 if DatastoreHashRepository:
     __all__.append('DatastoreHashRepository')
+
+if DatastoreSortedSetRepository:
+    __all__.append('DatastoreSortedSetRepository')
